==> koha-24.05.15.tar.gz: koha-24.05.15/circ/article-requests.pl <==
#!/usr/bin/perl

# Copyright 2015 ByWater Solutions
#
# This file is part of Koha.
#
# Koha is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Koha is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Koha; if not, see <http://www.gnu.org/licenses>.

use Modern::Perl;

use CGI qw ( -utf8 );

use C4::Auth qw( get_template_and_user );
use C4::Output qw( output_html_with_http_headers );
use Koha::ArticleRequests;

my $query = CGI->new;
my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
    {
        template_name   => "circ/article-requests.tt",
        query           => $query,
        type            => "intranet",
        flagsrequired   => { circulate => "circulate_remaining_permissions" },
    }
);

my $branchcode = defined( $query->param('branchcode') ) ? $query->param('branchcode') : C4::Context->userenv->{'branch'};

$template->param(
    branchcode                  => $branchcode,
    article_requests_requested  => Koha::ArticleRequests->requested($branchcode),
    article_requests_pending    => Koha::ArticleRequests->pending($branchcode),
    article_requests_processing => Koha::ArticleRequests->processing($branchcode),
);

output_html_with_http_headers $query, $cookie, $template->output;

==> koha-25.05.05.tar.gz: koha-25.05.05/circ/article-requests.pl <==
#!/usr/bin/perl

# Copyright 2015 ByWater Solutions
#
# This file is part of Koha.
#
# Koha is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Koha is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Koha; if not, see <http://www.gnu.org/licenses>.

use Modern::Perl;

use CGI qw ( -utf8 );

use C4::Auth   qw( get_template_and_user );
use C4::Output qw( output_html_with_http_headers );
use Koha::ArticleRequests;

my $query = CGI->new;
my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
    {
        template_name => "circ/article-requests.tt",
        query         => $query,
        type          => "intranet",
        flagsrequired => { circulate => "circulate_remaining_permissions" },
    }
);

my $branchcode =
    defined( $query->param('branchcode') ) ? $query->param('branchcode') : C4::Context->userenv->{'branch'};

$template->param(
    branchcode                  => $branchcode,
    article_requests_requested  => Koha::ArticleRequests->requested($branchcode),
    article_requests_pending    => Koha::ArticleRequests->pending($branchcode),
    article_requests_processing => Koha::ArticleRequests->processing($branchcode),
);

output_html_with_http_headers $query, $cookie, $template->output;
